@@ -11,19 +11,20 @@
 SEXP _unattr(SEXP x) {
     if (!isVector(x) || ATTRIB(x) == R_NilValue)
 	return x;
-    if (NAMED(x) > 1) {
+    if (MAYBE_SHARED(x)) {
 	SEXP s = x;
 	SEXP a = PROTECT(ATTRIB(x));
 	SET_ATTRIB(x, R_NilValue);
 	x = duplicate(x);
 	SET_ATTRIB(s, a);
-	UNPROTECT_PTR(a);
+	UNPROTECT(1);		/* a */
     } else
 	SET_ATTRIB(x, R_NilValue);
     if (OBJECT(x))
 	SET_OBJECT(x, 0);
     if (IS_S4_OBJECT(x))
-	UNSET_S4_OBJECT(x);
+	warning("'x' UNSET_S4_OBJECT no longer supported");
+	// UNSET_S4_OBJECT(x);
     return x;
 }
 
@@ -309,11 +310,11 @@ SEXP tcrossprod_stm_stm(SEXP x, SEXP y, SEXP pkgEnv, SEXP R_verbose) {
 	    if (vx != VECTOR_ELT(x, 2))
 		UNPROTECT(1);
 	    r = eval(PROTECT(LCONS(install(".tcrossprod_bailout"),
-			      CONS(x,
+		     PROTECT( CONS(x,
 			      CONS(y, 
 			      CONS(ScalarLogical(FALSE), 
-				   R_NilValue))))), pkgEnv);
-	    UNPROTECT(1);
+				   R_NilValue)))))), pkgEnv);
+	    UNPROTECT(2);
 	    return r;
 	}
 
@@ -333,11 +334,11 @@ SEXP tcrossprod_stm_stm(SEXP x, SEXP y, SEXP pkgEnv, SEXP R_verbose) {
 		if (vx != VECTOR_ELT(x, 2))
 		    UNPROTECT(1);
 		r = eval(PROTECT(LCONS(install(".tcrossprod_bailout"),
-				  CONS(x,
+			 PROTECT( CONS(x,
 				  CONS(y, 
 				  CONS(ScalarLogical(FALSE), 
-				       R_NilValue))))), pkgEnv);
-		UNPROTECT(1);
+				       R_NilValue)))))), pkgEnv);
+		UNPROTECT(2);
 		return r;
 	    }
 
@@ -544,12 +545,12 @@ SEXP tcrossprod_stm_matrix(SEXP x, SEXP R_y, SEXP pkgEnv, SEXP R_verbose,
 	    if (isNull(pkgEnv))
 		error("NA/NaN handling deactivated");
 	    r = eval(PROTECT(LCONS(install(".tcrossprod_bailout"),
-			      CONS(x,
+		     PROTECT( CONS(x,
 			      CONS(y, 
 			      CONS((R_transpose && *LOGICAL(R_transpose)) ?
 				    R_transpose : ScalarLogical(FALSE),
-				    R_NilValue))))), pkgEnv);
-	    UNPROTECT(1);
+				    R_NilValue)))))), pkgEnv);
+	    UNPROTECT(2);
 	    if (y != R_y)
 		UNPROTECT(1);
 	    return r;
@@ -622,7 +623,8 @@ SEXP tcrossprod_stm_matrix(SEXP x, SEXP R_y, SEXP pkgEnv, SEXP R_verbose,
 	_r = REAL(r);
 	for (int i = 0; i < n * m; i++)
 	    _r[i] = _y[i / n + (i % n) * m];
-	UNPROTECT_PTR(v);
+	UNPROTECT(2);		/* v, r */
+	PROTECT(r);
     } else {
 	// NOTE we rely on setAttrib to not check if the dimnames
 	//      are consistent with dim. 
